@@ -12,7 +12,7 @@ our @EXPORT = qw(
 	lcss	
 );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 require XSLoader;
 XSLoader::load('String::LCSS_XS', $VERSION);
@@ -33,8 +33,7 @@ String::LCSS_XS - Find The Longest Common Substring of Two Strings.
 
 =head1 DESCRIPTION
 
-
-String::LCSS_XS computes the Longest Common Substring shared by two strings.
+String::LCSS_XS computes the Longest Common Substring of two strings.
 It is a C implementation of L<String::LCSS> and uses a dynamic programming 
 algorithm with both runtime and memory usage of O(mn). 
 
@@ -53,11 +52,12 @@ algorithm with both runtime and memory usage of O(mn).
   
 =head1 BUGS AND LIMITATIONS
 
-Probably many. 
+Please report any bugs or feature requests to
+C<bug-string-lcss_xs@rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org>. 
 
-If there are multiple lcss (with the same length), then this implementation
-returns only the first
-found.
+If there are multiple lcss, then this implementation
+returns only the first found.
 
 String::LCSS_XS currently does not support L<String::LCSS> feature in list
 context where it returns the lcss positions. 
@@ -73,6 +73,7 @@ SYNOPSIS.
 =head1 SEE ALSO
 
 L<String::LCSS> - A pure perl implementation (but O(n^3) runtime)
+L<Tree::Suffix> - A lcss solution based on Suffix Trees
 
 Gusfield, Dan. I<Algorithms on Strings, Trees and Sequences: Computer Science
 and Computational Biology>. USA: Cambridge University Press. 
@@ -91,5 +92,28 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
 at your option, any later version of Perl 5 you may have available.
 
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
+
 
 =cut
